==> events-0.15.2-sources.jar: software/amazon/awscdk/services/events/cloudformation/EventBusPolicyResource.java <==
package software.amazon.awscdk.services.events.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-events-eventbuspolicy.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.8 (build 100f5ad)", date = "2018-11-08T13:06:32.245Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.events.$Module.class, fqn = "@aws-cdk/aws-events.cloudformation.EventBusPolicyResource")
public class EventBusPolicyResource extends software.amazon.awscdk.Resource {
    protected EventBusPolicyResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.events.cloudformation.EventBusPolicyResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::Events::EventBusPolicy``.
     * @param parent the ``cdk.Construct`` this ``EventBusPolicyResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``EventBusPolicyResource``
     */
    public EventBusPolicyResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.events.cloudformation.EventBusPolicyResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(@javax.annotation.Nullable final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(properties).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties() {
        return this.jsiiCall("renderProperties", java.util.Map.class);
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getEventBusPolicyId() {
        return this.jsiiGet("eventBusPolicyId", java.lang.String.class);
    }

    public software.amazon.awscdk.services.events.cloudformation.EventBusPolicyResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.events.cloudformation.EventBusPolicyResourceProps.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html
     */
    public static interface ConditionProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``EventBusPolicyResource.ConditionProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-key
         */
        java.lang.Object getKey();
        /**
         * ``EventBusPolicyResource.ConditionProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-key
         */
        void setKey(final java.lang.String value);
        /**
         * ``EventBusPolicyResource.ConditionProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-key
         */
        void setKey(final software.amazon.awscdk.Token value);
        /**
         * ``EventBusPolicyResource.ConditionProperty.Type``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-type
         */
        java.lang.Object getType();
        /**
         * ``EventBusPolicyResource.ConditionProperty.Type``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-type
         */
        void setType(final java.lang.String value);
        /**
         * ``EventBusPolicyResource.ConditionProperty.Type``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-type
         */
        void setType(final software.amazon.awscdk.Token value);
        /**
         * ``EventBusPolicyResource.ConditionProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-value
         */
        java.lang.Object getValue();
        /**
         * ``EventBusPolicyResource.ConditionProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-value
         */
        void setValue(final java.lang.String value);
        /**
         * ``EventBusPolicyResource.ConditionProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-value
         */
        void setValue(final software.amazon.awscdk.Token value);

        /**
         * @return a {@link Builder} of {@link ConditionProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link ConditionProperty}
         */
        final class Builder {
            @javax.annotation.Nullable
            private java.lang.Object _key;
            @javax.annotation.Nullable
            private java.lang.Object _type;
            @javax.annotation.Nullable
            private java.lang.Object _value;

            /**
             * Sets the value of Key
             * @param value ``EventBusPolicyResource.ConditionProperty.Key``
             * @return {@code this}
             */
            public Builder withKey(@javax.annotation.Nullable final java.lang.String value) {
                this._key = value;
                return this;
            }
            /**
             * Sets the value of Key
             * @param value ``EventBusPolicyResource.ConditionProperty.Key``
             * @return {@code this}
             */
            public Builder withKey(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this._key = value;
                return this;
            }
            /**
             * Sets the value of Type
             * @param value ``EventBusPolicyResource.ConditionProperty.Type``
             * @return {@code this}
             */
            public Builder withType(@javax.annotation.Nullable final java.lang.String value) {
                this._type = value;
                return this;
            }
            /**
             * Sets the value of Type
             * @param value ``EventBusPolicyResource.ConditionProperty.Type``
             * @return {@code this}
             */
            public Builder withType(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this._type = value;
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``EventBusPolicyResource.ConditionProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(@javax.annotation.Nullable final java.lang.String value) {
                this._value = value;
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``EventBusPolicyResource.ConditionProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this._value = value;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link ConditionProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public ConditionProperty build() {
                return new ConditionProperty() {
                    @javax.annotation.Nullable
                    private java.lang.Object $key = _key;
                    @javax.annotation.Nullable
                    private java.lang.Object $type = _type;
                    @javax.annotation.Nullable
                    private java.lang.Object $value = _value;

                    @Override
                    public java.lang.Object getKey() {
                        return this.$key;
                    }

                    @Override
                    public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                        this.$key = value;
                    }

                    @Override
                    public void setKey(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                        this.$key = value;
                    }

                    @Override
                    public java.lang.Object getType() {
                        return this.$type;
                    }

                    @Override
                    public void setType(@javax.annotation.Nullable final java.lang.String value) {
                        this.$type = value;
                    }

                    @Override
                    public void setType(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                        this.$type = value;
                    }

                    @Override
                    public java.lang.Object getValue() {
                        return this.$value;
                    }

                    @Override
                    public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                        this.$value = value;
                    }

                    @Override
                    public void setValue(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                        this.$value = value;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.events.cloudformation.EventBusPolicyResource.ConditionProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-key
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getKey() {
                return this.jsiiGet("key", java.lang.Object.class);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-key
             */
            @Override
            public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("key", value);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-key
             */
            @Override
            public void setKey(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this.jsiiSet("key", value);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Type``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-type
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getType() {
                return this.jsiiGet("type", java.lang.Object.class);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Type``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-type
             */
            @Override
            public void setType(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("type", value);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Type``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-type
             */
            @Override
            public void setType(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this.jsiiSet("type", value);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-value
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getValue() {
                return this.jsiiGet("value", java.lang.Object.class);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-value
             */
            @Override
            public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("value", value);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-value
             */
            @Override
            public void setValue(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this.jsiiSet("value", value);
            }
        }
    }
}

==> events-0.16.0-sources.jar: software/amazon/awscdk/services/events/cloudformation/EventBusPolicyResource.java <==
package software.amazon.awscdk.services.events.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-events-eventbuspolicy.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.10 (build 35934ad)", date = "2018-11-12T19:56:34.631Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.events.$Module.class, fqn = "@aws-cdk/aws-events.cloudformation.EventBusPolicyResource")
public class EventBusPolicyResource extends software.amazon.awscdk.Resource {
    protected EventBusPolicyResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.events.cloudformation.EventBusPolicyResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::Events::EventBusPolicy``.
     * @param parent the ``cdk.Construct`` this ``EventBusPolicyResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``EventBusPolicyResource``
     */
    public EventBusPolicyResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.events.cloudformation.EventBusPolicyResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getEventBusPolicyId() {
        return this.jsiiGet("eventBusPolicyId", java.lang.String.class);
    }

    public software.amazon.awscdk.services.events.cloudformation.EventBusPolicyResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.events.cloudformation.EventBusPolicyResourceProps.class);
    }
    /**
     * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html
     */
    public static interface ConditionProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * ``EventBusPolicyResource.ConditionProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-key
         */
        java.lang.Object getKey();
        /**
         * ``EventBusPolicyResource.ConditionProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-key
         */
        void setKey(final java.lang.String value);
        /**
         * ``EventBusPolicyResource.ConditionProperty.Key``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-key
         */
        void setKey(final software.amazon.awscdk.Token value);
        /**
         * ``EventBusPolicyResource.ConditionProperty.Type``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-type
         */
        java.lang.Object getType();
        /**
         * ``EventBusPolicyResource.ConditionProperty.Type``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-type
         */
        void setType(final java.lang.String value);
        /**
         * ``EventBusPolicyResource.ConditionProperty.Type``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-type
         */
        void setType(final software.amazon.awscdk.Token value);
        /**
         * ``EventBusPolicyResource.ConditionProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-value
         */
        java.lang.Object getValue();
        /**
         * ``EventBusPolicyResource.ConditionProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-value
         */
        void setValue(final java.lang.String value);
        /**
         * ``EventBusPolicyResource.ConditionProperty.Value``
         * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-value
         */
        void setValue(final software.amazon.awscdk.Token value);

        /**
         * @return a {@link Builder} of {@link ConditionProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link ConditionProperty}
         */
        final class Builder {
            @javax.annotation.Nullable
            private java.lang.Object _key;
            @javax.annotation.Nullable
            private java.lang.Object _type;
            @javax.annotation.Nullable
            private java.lang.Object _value;

            /**
             * Sets the value of Key
             * @param value ``EventBusPolicyResource.ConditionProperty.Key``
             * @return {@code this}
             */
            public Builder withKey(@javax.annotation.Nullable final java.lang.String value) {
                this._key = value;
                return this;
            }
            /**
             * Sets the value of Key
             * @param value ``EventBusPolicyResource.ConditionProperty.Key``
             * @return {@code this}
             */
            public Builder withKey(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this._key = value;
                return this;
            }
            /**
             * Sets the value of Type
             * @param value ``EventBusPolicyResource.ConditionProperty.Type``
             * @return {@code this}
             */
            public Builder withType(@javax.annotation.Nullable final java.lang.String value) {
                this._type = value;
                return this;
            }
            /**
             * Sets the value of Type
             * @param value ``EventBusPolicyResource.ConditionProperty.Type``
             * @return {@code this}
             */
            public Builder withType(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this._type = value;
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``EventBusPolicyResource.ConditionProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(@javax.annotation.Nullable final java.lang.String value) {
                this._value = value;
                return this;
            }
            /**
             * Sets the value of Value
             * @param value ``EventBusPolicyResource.ConditionProperty.Value``
             * @return {@code this}
             */
            public Builder withValue(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this._value = value;
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link ConditionProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public ConditionProperty build() {
                return new ConditionProperty() {
                    @javax.annotation.Nullable
                    private java.lang.Object $key = _key;
                    @javax.annotation.Nullable
                    private java.lang.Object $type = _type;
                    @javax.annotation.Nullable
                    private java.lang.Object $value = _value;

                    @Override
                    public java.lang.Object getKey() {
                        return this.$key;
                    }

                    @Override
                    public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                        this.$key = value;
                    }

                    @Override
                    public void setKey(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                        this.$key = value;
                    }

                    @Override
                    public java.lang.Object getType() {
                        return this.$type;
                    }

                    @Override
                    public void setType(@javax.annotation.Nullable final java.lang.String value) {
                        this.$type = value;
                    }

                    @Override
                    public void setType(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                        this.$type = value;
                    }

                    @Override
                    public java.lang.Object getValue() {
                        return this.$value;
                    }

                    @Override
                    public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                        this.$value = value;
                    }

                    @Override
                    public void setValue(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                        this.$value = value;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.events.cloudformation.EventBusPolicyResource.ConditionProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-key
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getKey() {
                return this.jsiiGet("key", java.lang.Object.class);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-key
             */
            @Override
            public void setKey(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("key", value);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Key``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-key
             */
            @Override
            public void setKey(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this.jsiiSet("key", value);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Type``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-type
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getType() {
                return this.jsiiGet("type", java.lang.Object.class);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Type``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-type
             */
            @Override
            public void setType(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("type", value);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Type``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-type
             */
            @Override
            public void setType(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this.jsiiSet("type", value);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-value
             */
            @Override
            @javax.annotation.Nullable
            public java.lang.Object getValue() {
                return this.jsiiGet("value", java.lang.Object.class);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-value
             */
            @Override
            public void setValue(@javax.annotation.Nullable final java.lang.String value) {
                this.jsiiSet("value", value);
            }

            /**
             * ``EventBusPolicyResource.ConditionProperty.Value``
             * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-events-eventbuspolicy-condition.html#cfn-events-eventbuspolicy-condition-value
             */
            @Override
            public void setValue(@javax.annotation.Nullable final software.amazon.awscdk.Token value) {
                this.jsiiSet("value", value);
            }
        }
    }
}
